module.exports = defineTest({
	description: 'does not break flow from inside loops that may not have executed'
});
